==> simsu-1.3.1-1-src.tar.xz: simsu-1.3.1/translations/simsu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="81"/>
        <location filename="../src/board.cpp" line="96"/>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalba:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos Kalba&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="175"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <location filename="../src/pattern.h" line="78"/>
        <source>180° Rotational</source>
        <translation>180° Pasukama</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="79"/>
        <source>Full Rotational</source>
        <translation>Pilnai Pasukama</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="80"/>
        <source>Horizontal</source>
        <translation>Horizontali</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="81"/>
        <source>Vertical</source>
        <translation>Vertikali</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="82"/>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontali ir Vertikali</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="83"/>
        <source>Diagonal</source>
        <translation>Įstrižainė</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="84"/>
        <source>Anti-Diagonal</source>
        <translation>Anti-Įstrižainė</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="85"/>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Įstrižainė ir Anti-Įstrižainė</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="86"/>
        <source>Full Dihedral</source>
        <translation>Pilna sudaroma dviejų susikertančių plokštumų</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="87"/>
        <source>Random</source>
        <translation>Atsitiktinė</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="88"/>
        <source>None</source>
        <translation>Jokia</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="37"/>
        <location filename="../src/window.cpp" line="319"/>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="104"/>
        <source>Pen</source>
        <translation>Tušinukas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="108"/>
        <source>Pencil</source>
        <translation>Pieštukas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>Highlight</source>
        <translation>Paryškinti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="158"/>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;Details</source>
        <translation>&amp;Išsamiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>&amp;Move</source>
        <translation>&amp;Judesiai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <source>&amp;Undo</source>
        <translation>An&amp;uliuoti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>&amp;Redo</source>
        <translation>Atku&amp;rti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Check</source>
        <translation>&amp;Tikrinti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>&amp;Settings</source>
        <translation>Nu&amp;statymai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Automatiškai Perjungti Veiksenas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="178"/>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Plačiaekranis Lygiavimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>Application &amp;Language...</source>
        <translation>Programos Ka&amp;lba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="185"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>&amp;Controls</source>
        <translation>&amp;Valdymas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="189"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="191"/>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="233"/>
        <source>New Game</source>
        <translation>Naujas Žaidimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Dancing Links</source>
        <translation>Šokančios Nuorodos</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <location filename="../src/window.cpp" line="291"/>
        <source>Slice and Dice</source>
        <translation>Gabaliukais</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="256"/>
        <source>Random</source>
        <translation>Atsitiktinis</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Symmetry:</source>
        <translation>Simetrija:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Seed:</source>
        <translation>Išdėstymas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="294"/>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Simetrija:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algoritmas:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Išdėstymas:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Valdymas Pėle:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Kairiojo mygtuko paspaudimas:&lt;/b&gt; Perjungia skaičių tušinuko veiksenoje&lt;br&gt;&lt;b&gt;Dešiniojo mygtuko paspaudimas:&lt;/b&gt; Perjungia skaičių pieštuko veiksenoje&lt;br&gt;&lt;b&gt;Slinkimo ratukas:&lt;/b&gt; Keičia dabartinį skaičių&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Valdymas Klaviatūra:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Krypties klavišai:&lt;/b&gt; Perkelia pasirinkimą&lt;br&gt;&lt;b&gt;Skaičių klavišai:&lt;/b&gt; Perjungia atsakymo arba užrašo reikšmes&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Perjungia tarp tušinuko ir pieštuko veiksenos&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Paryškina visus esamo skaičiaus egzempliorius&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>About Simsu</source>
        <translation>Apie Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="320"/>
        <source>A basic Sudoku game</source>
        <translation>Paprastas Sudoku žaidimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="321"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorinės Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="322"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>

==> simsu-1.3.3-1-src.tar.xz: simsu-1.3.3/translations/simsu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalba:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>180° pasukama</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Pilnai pasukama</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontali</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikali</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontali ir vertikali</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Įstrižainė</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Anti-įstrižainė</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Įstrižainė ir anti-įstrižainė</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Pilna sudaroma dviejų susikertančių plokštumų</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Atsitiktinė</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Jokia</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Tušinukas</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pieštukas</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Paryškinti</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Išsamiau</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Judesiai</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>An&amp;uliuoti</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Atku&amp;rti</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>&amp;Tikrinti</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Nu&amp;statymai</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Automatiškai perjungti veiksenas</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Plačiaekranis lygiavimas</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Valdymas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Dancing Links</source>
        <translation>Šokančios nuorodos</translation>
    </message>
    <message>
        <source>Slice and Dice</source>
        <translation>Gabaliukais</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Atsitiktinis</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Simetrija:</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Išdėstymas:</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Simetrija:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algoritmas:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Išdėstymas:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Valdymas pele:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Kairiojo mygtuko paspaudimas:&lt;/b&gt; Perjungia skaičių tušinuko veiksenoje&lt;br&gt;&lt;b&gt;Dešiniojo mygtuko paspaudimas:&lt;/b&gt; Perjungia skaičių pieštuko veiksenoje&lt;br&gt;&lt;b&gt;Slinkimo ratukas:&lt;/b&gt; Keičia dabartinį skaičių&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Valdymas Klaviatūra:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Krypties klavišai:&lt;/b&gt; Perkelia pasirinkimą&lt;br&gt;&lt;b&gt;Skaičių klavišai:&lt;/b&gt; Perjungia atsakymo arba užrašo reikšmes&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Perjungia tarp tušinuko ir pieštuko veiksenos&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Paryškina visus esamo skaičiaus egzempliorius&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>Apie Simsu</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Paprastas Sudoku žaidimas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>
